@@ -24,16 +24,18 @@
     limitations under the License.
 """
 import sys
+import argparse
 
 from fs import open_fs, path
-from PyQt5 import QtWidgets, QtGui
-from fslib import ui_filepicker
+from PyQt5 import QtWidgets
+from fslib import ui_filepicker, __version__
 from fslib.utils import match_extension
 
 class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
     def __init__(self, parent=None, fs_url=u"~/", file_pattern=u'*.*', title=u'FS File Picker'):
         super(FilePicker, self).__init__(parent)
         self.setupUi(self)
+        self.selected_dir = None
         self.filename = None
         self.setWindowTitle(title)
         self.fs_url = fs_url
@@ -47,33 +49,50 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.buttonBox.button(self.buttonBox.Open).clicked.connect(self.open)
 
     def browse_folder(self):
+        """
+        walks through all folders and selects first directory
+        """
         self.DirList.clear()
         self.home_fs = open_fs(self.fs_url)
         self.DirList.addItem(u'.')
-        for dir_path in self.home_fs.walk.dirs(ignore_errors=True):
+        for dir_path in sorted(self.home_fs.walk.dirs(ignore_errors=True)):
             self.DirList.addItem(dir_path)
         self.selection_directory(0)
         self.DirList.currentIndexChanged.connect(self.selection_directory)
 
     def selection_directory(self, i):
+        """
+        Fills the filenames based on file_type into a FileList
+
+        :param i: index of selelection
+        """
         self.last_index = i
-        selected_dir = self.DirList.currentText()
+        self.selected_dir = self.DirList.currentText()
         self.FileList.clear()
         file_type = self.file_type.text()
-        for item in self.home_fs.listdir(selected_dir):
+        for item in sorted(self.home_fs.listdir(self.selected_dir)):
             if not self.home_fs.isdir(item) and match_extension(item, [file_type]):
-                    self.FileList.addItem(item)
+                self.FileList.addItem(item)
         if self.last_index == 0:
             self.FileList.setCurrentRow(0)
 
     def selection_file_type(self):
+        """
+        Action for line edit of file type
+        """
         self.selection_directory(self.last_index)
         self.FileList.setCurrentRow(-1)
 
     def cancel(self):
+        """
+        Action on cancel button
+        """
         self.close()
 
     def open(self):
+        """
+        Action on open button
+        """
         try:
             self.filename = self.FileList.item(self.FileList.currentRow()).text()
         except AttributeError:
@@ -83,16 +102,40 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
 
 
 def fs_filepicker(parent=None, fs_url=u'~/', file_pattern=u'*.*', title=u'FS File Picker'):
-    if parent is None:
-        app = QtWidgets.QApplication(sys.argv)
-    form = FilePicker(parent, fs_url, file_pattern, title=title)
-    form.show()
-    if parent is None:
-        app.exec_()
+    """
+    Selects a file by FilePicker for a given pyfilesystem2 Url.
 
-    fs_path = path.combine(form.fs_url, form.filename)
-    return fs_path
+    :param parent: parent Widget
+    :param fs_url: pyfilesystem2 url
+    :param file_pattern: filter pattern of pyfilesystem2
+    :param title: title of QtWidget
+    :return: selected filename
+    """
+    fp = FilePicker(parent, fs_url, file_pattern, title=title)
+    fp.setModal(True)
+    fp.exec_()
+    filename = None
+    if fp.filename is not None:
+        filename = path.combine(fp.fs_url, path.join(fp.selected_dir, fp.filename))
+    return filename
+
+def main():
+    parser = argparse.ArgumentParser()
+    parser.add_argument("-v", "--version", help="show version", action="store_true", default=False)
+    parser.add_argument("-u", "--fs_url", help="fs url to filesystem", default=u"~/")
+    parser.add_argument("-f", "--file_pattern", help="file pattern", default=u"*.*")
+    parser.add_argument("-t", "--title", help="title of window", default=u'FS File Picker')
+    args = parser.parse_args()
+    if args.version:
+        print("***********************************************************************")
+        print("\n            File Picker Version \n")
+        print("***********************************************************************")
+        print("Version:", __version__)
+        sys.exit()
+    app = QtWidgets.QApplication([])
+    fs_filepicker(parent=None, fs_url=args.fs_url, file_pattern=args.file_pattern, title=args.title)
 
 if __name__ == '__main__':
-    print(fs_filepicker())
+    print(main())
+
 
